import java.io.FileReader;
import java.io.Reader;
import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamConstants;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;

public class XMLStreamReaderDemo {
    public static void main(String[] args) {
        try {
            // Create an XMLInputFactory
            XMLInputFactory factory = XMLInputFactory.newInstance();
            
            // Create a FileReader of source.xml
            Reader fileReader = new FileReader("source.xml");
            XMLStreamReader reader =
                    factory.createXMLStreamReader(fileReader);
            
            // Iterate over the XML
            while (reader.hasNext()) {
                process(reader);
                reader.next();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    
    private static void process(XMLStreamReader reader)
    throws XMLStreamException {
        
        // Event type
        int eventType = reader.getEventType();
        
        // Check event type
        switch (eventType) {
            case XMLStreamConstants.START_ELEMENT:
                // Display the element's local name
                System.out.println("Start element: " + reader.getLocalName());
                
                // Display all attributes of the element
                int count = reader.getAttributeCount();
                for (int i = 0; i < count; i++) {
                    String name = reader.getAttributeLocalName(i);
                    String value = reader.getAttributeValue(i);
                    System.out.println("\tAttribute name/value: " + name + "/" + value);
                }
                break;
                
            case XMLStreamConstants.END_ELEMENT:
                System.out.println("End element: " + reader.getLocalName());
                break;
                
            case XMLStreamConstants.CHARACTERS:
                System.out.println("Text: " + reader.getText());
                break;
            default:
                break;
        }
    }
}